@@ -5,7 +5,7 @@ package App::Pastebin::Create;
 # FILE HOLDER/THIS IS COMMAND LINE APP, executable name is pastebin-create
 # The executable located in bin/
 # type pastebin -h for usage
-our $VERSION = '1.0021'; # VERSION
+our $VERSION = '1.0022'; # VERSION
 
 __END__
 
@@ -19,7 +19,7 @@ App::Pastebin::Create - Simple CLI App to create and upload to Pastebin.com
 
 =head1 VERSION
 
-version 1.0021
+version 1.0022
 
 =head1 SYNOPSIS
 
@@ -63,6 +63,13 @@ OPTIONAL
 
 Your paste title description.
 
+=head1 Testing & Manual Installation
+
+	perl Makefile.pl && make test
+	
+	# install
+	make install
+
 =head1 SEE ALSO
 
 L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create>
